@@ -43,7 +43,7 @@
 #define EVDEV_PROP_WHEEL_INERTIA "Evdev Wheel Emulation Inertia"
 /* CARD16 */
 #define EVDEV_PROP_WHEEL_TIMEOUT "Evdev Wheel Emulation Timeout"
-/* CARD8, value range 0-32, 0 to disable a value */
+/* CARD8, value range 0-32, 0 to always scroll */
 #define EVDEV_PROP_WHEEL_BUTTON "Evdev Wheel Emulation Button"
 
 /* Drag lock */
@@ -56,6 +56,14 @@
 
 /* Reopen attempts. */
 /* CARD8 */
-#define EVDEV_PROP_REOPEN "Evdev Reopen Attempts"
+#define EVDEV_PROP_REOPEN "Evdev Reopen Attempts" /* OBSOLETE */
+
+/* Run-time calibration */
+/* CARD32, 4 values [minx, maxx, miny, maxy], or no values for unset */
+#define EVDEV_PROP_CALIBRATION "Evdev Axis Calibration"
+
+/* Swap x and y axis. */
+/* BOOL */
+#define EVDEV_PROP_SWAP_AXES "Evdev Axes Swap"
 
 #endif
